==> GOOGLE-ADWORDS-PERL-CLIENT-2.10.0.tar.gz: GOOGLE-ADWORDS-PERL-CLIENT-2.10.0/lib/Google/Ads/AdWords/v201302/FeedItemService/FeedItemServiceInterfacePort.pm <==
package Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort;
use strict;
use warnings;
use Class::Std::Fast::Storable;
use Scalar::Util qw(blessed);
use base qw(SOAP::WSDL::Client::Base);

# only load if it hasn't been loaded before
require Google::Ads::AdWords::v201302::TypeMaps::FeedItemService
    if not Google::Ads::AdWords::v201302::TypeMaps::FeedItemService->can('get_class');

sub START {
    $_[0]->set_proxy('https://adwords.google.com/api/adwords/cm/v201302/FeedItemService') if not $_[2]->{proxy};
    $_[0]->set_class_resolver('Google::Ads::AdWords::v201302::TypeMaps::FeedItemService')
        if not $_[2]->{class_resolver};

    $_[0]->set_prefix($_[2]->{use_prefix}) if exists $_[2]->{use_prefix};
}

sub get {
    my ($self, $body, $header) = @_;
    die "get must be called as object method (\$self is <$self>)" if not blessed($self);
    return $self->SUPER::call({
        operation => 'get',
        soap_action => '',
        style => 'document',
        body => {
            

           'use'            => 'literal',
            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle   => '',
            parts           =>  [qw( Google::Ads::AdWords::v201302::FeedItemService::get )],
        },
        header => {
            


           'use' => 'literal',
            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle => '',
            parts => [qw( Google::Ads::AdWords::v201302::FeedItemService::RequestHeader )],
        },
        headerfault => {
            
        }
    }, $body, $header);
}


sub mutate {
    my ($self, $body, $header) = @_;
    die "mutate must be called as object method (\$self is <$self>)" if not blessed($self);
    return $self->SUPER::call({
        operation => 'mutate',
        soap_action => '',
        style => 'document',
        body => {
            

           'use'            => 'literal',
            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle   => '',
            parts           =>  [qw( Google::Ads::AdWords::v201302::FeedItemService::mutate )],
        },
        header => {
            


           'use' => 'literal',
            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle => '',
            parts => [qw( Google::Ads::AdWords::v201302::FeedItemService::RequestHeader )],
        },
        headerfault => {
            
        }
    }, $body, $header);
}




1;



__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort - SOAP Interface for the FeedItemService Web Service

=head1 SYNOPSIS

 use Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort;
 my $interface = Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort->new();

 my $response;
 $response = $interface->get();
 $response = $interface->mutate();



=head1 DESCRIPTION

SOAP Interface for the FeedItemService web service
located at https://adwords.google.com/api/adwords/cm/v201302/FeedItemService.

=head1 SERVICE FeedItemService



=head2 Port FeedItemServiceInterfacePort



=head1 METHODS

=head2 General methods

=head3 new

Constructor.

All arguments are forwarded to L<SOAP::WSDL::Client|SOAP::WSDL::Client>.

=head2 SOAP Service methods

Method synopsis is displayed with hash refs as parameters.

The commented class names in the method's parameters denote that objects
of the corresponding class can be passed instead of the marked hash ref.

You may pass any combination of objects, hash and list refs to these
methods, as long as you meet the structure.

List items (i.e. multiple occurences) are not displayed in the synopsis.
You may generally pass a list ref of hash refs (or objects) instead of a hash
ref - this may result in invalid XML if used improperly, though. Note that
SOAP::WSDL always expects list references at maximum depth position.

XML attributes are not displayed in this synopsis and cannot be set using
hash refs. See the respective class' documentation for additional information.



=head3 get

Returns a list of FeedItems that meet the selector criteria. @param selector Determines which FeedItems to return. If empty all FeedItems are returned. @return The list of FeedItems. @throws ApiException Indicates a problem with the request. 

Returns a L<Google::Ads::AdWords::v201302::FeedItemService::getResponse|Google::Ads::AdWords::v201302::FeedItemService::getResponse> object.

 $response = $interface->get( {
    selector =>  $a_reference_to, # see Google::Ads::AdWords::v201302::Selector
  },,
 );

=head3 mutate

Add, remove, and set FeedItems. @param operations The operations to apply. @return The resulting FeedItems. @throws ApiException Indicates a problem with the request. 

Returns a L<Google::Ads::AdWords::v201302::FeedItemService::mutateResponse|Google::Ads::AdWords::v201302::FeedItemService::mutateResponse> object.

 $response = $interface->mutate( {
    operations =>  $a_reference_to, # see Google::Ads::AdWords::v201302::FeedItemOperation
  },,
 );



=head1 AUTHOR

Generated by SOAP::WSDL on Tue Mar  5 13:49:45 2013

=cut

==> GOOGLE-ADWORDS-PERL-CLIENT-2.12.0.tar.gz: GOOGLE-ADWORDS-PERL-CLIENT-2.12.0/lib/Google/Ads/AdWords/v201302/FeedItemService/FeedItemServiceInterfacePort.pm <==
package Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort;
use strict;
use warnings;
use Class::Std::Fast::Storable;
use Scalar::Util qw(blessed);
use base qw(SOAP::WSDL::Client::Base);

# only load if it hasn't been loaded before
require Google::Ads::AdWords::v201302::TypeMaps::FeedItemService
    if not Google::Ads::AdWords::v201302::TypeMaps::FeedItemService->can('get_class');

sub START {
    $_[0]->set_proxy('https://adwords.google.com/api/adwords/cm/v201302/FeedItemService') if not $_[2]->{proxy};
    $_[0]->set_class_resolver('Google::Ads::AdWords::v201302::TypeMaps::FeedItemService')
        if not $_[2]->{class_resolver};

    $_[0]->set_prefix($_[2]->{use_prefix}) if exists $_[2]->{use_prefix};
}

sub get {
    my ($self, $body, $header) = @_;
    die "get must be called as object method (\$self is <$self>)" if not blessed($self);
    return $self->SUPER::call({
        operation => 'get',
        soap_action => '',
        style => 'document',
        body => {
            

           'use'            => 'literal',
            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle   => '',
            parts           =>  [qw( Google::Ads::AdWords::v201302::FeedItemService::get )],
        },
        header => {
            


           'use' => 'literal',
            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle => '',
            parts => [qw( Google::Ads::AdWords::v201302::FeedItemService::RequestHeader )],
        },
        headerfault => {
            
        }
    }, $body, $header);
}


sub mutate {
    my ($self, $body, $header) = @_;
    die "mutate must be called as object method (\$self is <$self>)" if not blessed($self);
    return $self->SUPER::call({
        operation => 'mutate',
        soap_action => '',
        style => 'document',
        body => {
            

           'use'            => 'literal',
            namespace       => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle   => '',
            parts           =>  [qw( Google::Ads::AdWords::v201302::FeedItemService::mutate )],
        },
        header => {
            


           'use' => 'literal',
            namespace => 'http://schemas.xmlsoap.org/wsdl/soap/',
            encodingStyle => '',
            parts => [qw( Google::Ads::AdWords::v201302::FeedItemService::RequestHeader )],
        },
        headerfault => {
            
        }
    }, $body, $header);
}




1;



__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort - SOAP Interface for the FeedItemService Web Service

=head1 SYNOPSIS

 use Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort;
 my $interface = Google::Ads::AdWords::v201302::FeedItemService::FeedItemServiceInterfacePort->new();

 my $response;
 $response = $interface->get();
 $response = $interface->mutate();



=head1 DESCRIPTION

SOAP Interface for the FeedItemService web service
located at https://adwords.google.com/api/adwords/cm/v201302/FeedItemService.

=head1 SERVICE FeedItemService



=head2 Port FeedItemServiceInterfacePort



=head1 METHODS

=head2 General methods

=head3 new

Constructor.

All arguments are forwarded to L<SOAP::WSDL::Client|SOAP::WSDL::Client>.

=head2 SOAP Service methods

Method synopsis is displayed with hash refs as parameters.

The commented class names in the method's parameters denote that objects
of the corresponding class can be passed instead of the marked hash ref.

You may pass any combination of objects, hash and list refs to these
methods, as long as you meet the structure.

List items (i.e. multiple occurences) are not displayed in the synopsis.
You may generally pass a list ref of hash refs (or objects) instead of a hash
ref - this may result in invalid XML if used improperly, though. Note that
SOAP::WSDL always expects list references at maximum depth position.

XML attributes are not displayed in this synopsis and cannot be set using
hash refs. See the respective class' documentation for additional information.



=head3 get

Returns a list of FeedItems that meet the selector criteria. @param selector Determines which FeedItems to return. If empty all FeedItems are returned. @return The list of FeedItems. @throws ApiException Indicates a problem with the request. 

Returns a L<Google::Ads::AdWords::v201302::FeedItemService::getResponse|Google::Ads::AdWords::v201302::FeedItemService::getResponse> object.

 $response = $interface->get( {
    selector =>  $a_reference_to, # see Google::Ads::AdWords::v201302::Selector
  },,
 );

=head3 mutate

Add, remove, and set FeedItems. @param operations The operations to apply. @return The resulting FeedItems. @throws ApiException Indicates a problem with the request. 

Returns a L<Google::Ads::AdWords::v201302::FeedItemService::mutateResponse|Google::Ads::AdWords::v201302::FeedItemService::mutateResponse> object.

 $response = $interface->mutate( {
    operations =>  $a_reference_to, # see Google::Ads::AdWords::v201302::FeedItemOperation
  },,
 );



=head1 AUTHOR

Generated by SOAP::WSDL on Wed Jul 10 13:55:16 2013

=cut
